@@ -34,6 +34,7 @@ import urllib2
 import os
 import literals
 import ConfigParser
+from clint.textui import colored
 
 
 class Result(object):
@@ -131,11 +132,11 @@ class GithubFacade(object):
 
         if self.basic_auth:
             return requests.post(url, data=data_json, headers=headers,
-                    auth=(self.username, self.credential))
+                                 auth=(self.username, self.credential))
         else:
             params = {'access_token': self.credential}
             return requests.post(url, data=data_json, headers=headers,
-                    params=params)
+                                 params=params)
 
     def update_gist(self, payload):
         """ Update an existent Gist via PATCH method.
@@ -150,11 +151,11 @@ class GithubFacade(object):
 
         if self.basic_auth:
             return requests.patch(url, data=data_json, headers=headers,
-                    auth=(self.username, self.credential))
+                                  auth=(self.username, self.credential))
         else:
             params = {'access_token': self.credential}
             return requests.patch(url, data=data_json, headers=headers,
-                    params=params)
+                                  params=params)
 
     def delete_gist(self, id_gist):
         """ Delete an existent Gist.
@@ -165,7 +166,7 @@ class GithubFacade(object):
         url = self.ENDPOINT_GIST % (id_gist)
         if self.basic_auth:
             return requests.delete(url,
-                    auth=(self.username, self.credential))
+                                   auth=(self.username, self.credential))
         else:
             params = {'access_token': self.credential}
             return requests.delete(url, params=params)
@@ -174,7 +175,7 @@ class GithubFacade(object):
         """ List the authorizations for the given user. """
 
         return requests.get(self.ENDPOINT_AUTH,
-                auth=(self.username, self.credential))
+                            auth=(self.username, self.credential))
 
     def fork_gist(self, gist_id):
         """ Requests to GitHub Gist API to fork a gist. """
@@ -193,7 +194,7 @@ class GithubFacade(object):
         if self.basic_auth:
             headers = {'Content-length': '0'}
             return requests.put(url, auth=(self.username, self.credential),
-                    headers=headers)
+                                headers=headers)
         else:
             params = {'access_token': self.credential}
             headers = {'Content-length': '0'}
@@ -219,7 +220,7 @@ class GithubFacade(object):
         headers = {'Content-type': self.APPLICATION_JSON}
         data_json = json.dumps(payload, indent=2)
         return requests.post(url, data=data_json, headers=headers,
-                auth=(self.username, self.credential))
+                             auth=(self.username, self.credential))
 
 
 class GistsConfigurer(object):
@@ -299,7 +300,8 @@ def download(url, destination_dir, file_name, file_size):
     """
 
     destination_path = os.path.join(destination_dir, file_name)
-    print (literals.DOWNLOADING % (url, destination_path, file_size))
+    print colored.green(literals.DOWNLOADING %
+                        (url, destination_path, file_size))
 
     # Open the remote url as a file, read it and write it in
     # target directory
